# Videochef

Read me test

Tested and works well with:
* AVI files, encoded with `ffv1`, and pixel format `gray8`
* MP4 files, encoded with `h264`, and pixel format `yuvj420`
* Likely works well with most grayscale AVIs.

